data = '''
abbr.
A.D.
adj.
adv.
A.H.
a.m.
A.M.
anon.
arr.
Assoc.
Asst.
attn.
Av.
Ave.
b.
B.A.
B.C.
B.C.E.
B.Ed.
B.Litt
Blvd.
B.Mus
B.Phil
Br.
Brig.
Bros.
B.S.
c.
C.
Capt.
Cdr.
C.E.
cent.
cert.
cf.
chap.
C.-in-C.
Co.
col.
Col.
Con.
conj.
cont.
Corp.
cp.
Cpl.
ct.
Ct.
cu.
d.
D.
D.A.
d.b.a.
deg.
Dem.
dep.
Dept.
det.
Div.
D.Litt
do.
D.O.B.
doz.
Dr.
D.T.'s
ed.
e.g.
enc.
encl.
eng.
esp.
Esq.
etc.
exclam.
ext.
f.
ff.
fig.
f.o.b.
Fr.
ft.
Ft.
gal.
Gen.
gm.
govt.
Gt.
H.E.
H.M.
Hon.
h.p.
hr.
I.
ib.
ibid.
i.e.
in.
inc.
Inc.
incl.
Ind.
Is.
Jr.
l.
L.A.
Lab.
lat.
lb.
l.c.
l.h.
Lieut.
LL.B
LL.D
LL.M
long.
Lt.
m.
M.A.
Maj.
max.
med.
Messrs.
Mgr.
min.
M.O.
Mr.
Mrs.
M.S.
Ms.
Mt.
n.
N.B.
neg.
No.
N.Z.
o.b.o.
o.n.o.
Op.
p.
p.a.
par.
para.
p.d.q.
P.E.
Ph.D.
pl.
Pl.
p.m.
P.M.
pop.
p.p.
prep.
Prof.
pron.
p.s.i.
pt.
p.w.
Q.E.D.
q.v.
R.
Rd.
ref.
Rep.
Rev.
r.h.
R.I.P.
R.S.V.P.
sec.
Sec.
Secy.
Sen.
Sgt.
sing.
So.
Soc.
sq.
Sq.
Sr.
st.
St.
Supt.
symb.
tel.
temp.
T.M.
u.c.
U.K.
U.N.
Univ.
U.S.
U.S.A.
viz.
vol.
yr.
G.L.O.W.
U!S!A!
Washingto, D.C.
Jan.
Feb.
Mar.
Apr.
Jun.
Jul.
Aug.
Sept.
Sep.
Oct.
Nov.
Dec.
Mon.
Tues.
Wed.
Thur.
Fri.
Sat.
Sun.
mm.
dd.
Co.,
Ltd.,
S.
N. 
S.E.
H.K.
N.Y.
lng.
D.C.
'''
